@@ -83,12 +83,24 @@ describe 'oslo::db' do
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pymongo').with(
           :ensure => 'present',
           :name   => 'python-pymongo',
           :tag    => 'openstack'
         )
       end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-pymongo')
+        end
+      end
     end
 
     context 'with specific mongodb connection string' do
@@ -117,6 +129,18 @@ describe 'oslo::db' do
       it 'install the proper backend package' do
         is_expected.to contain_package('python-psycopg2').with(:ensure => 'present')
       end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-psycopg2')
+        end
+      end
     end
 
     context 'with incorrect database_connection string' do
@@ -143,12 +167,24 @@ describe 'oslo::db' do
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pymysql').with(
           :ensure => 'present',
           :name   => 'python-pymysql',
           :tag    => 'openstack'
         )
       end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-pymysql')
+        end
+      end
     end
 
     context 'with sqlite backend' do
@@ -157,12 +193,24 @@ describe 'oslo::db' do
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pysqlite2').with(
           :ensure => 'present',
           :name   => 'python-pysqlite2',
           :tag    => 'openstack'
         )
       end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-pysqlite2')
+        end
+      end
     end
   end
 
@@ -171,8 +219,6 @@ describe 'oslo::db' do
       let :params do
         { :connection => 'mysql+pymysql:///db:db@localhost/db', }
       end
-
-      it { is_expected.not_to contain_package('db_backend_package') }
     end
   end
 
